@@ -52,8 +52,7 @@ from pygame_menu.locals import POSITION_NORTHWEST, POSITION_SOUTHEAST, ALIGN_CEN
     CURSOR_ARROW
 from pygame_menu._scrollarea import get_scrollbars_from_position
 from pygame_menu.utils import assert_alignment, assert_cursor, assert_vector, \
-    assert_position, assert_color, is_callable, format_color, assert_position_vector, \
-    warn
+    assert_position, assert_color, is_callable, format_color, assert_position_vector
 from pygame_menu.widgets import HighlightSelection, NoneSelection, MENUBAR_STYLE_ADAPTIVE, \
     MENUBAR_STYLE_SIMPLE, MENUBAR_STYLE_TITLE_ONLY, MENUBAR_STYLE_TITLE_ONLY_DIAGONAL, \
     MENUBAR_STYLE_NONE, MENUBAR_STYLE_UNDERLINE, MENUBAR_STYLE_UNDERLINE_TITLE
@@ -413,14 +412,6 @@ class Theme(object):
         self.widget_tab_size = self._get(kwargs, 'widget_tab_size', int, 4)
         self.widget_url_color = self._get(kwargs, 'widget_url_color', 'color', (6, 69, 173))
 
-        # Compatibility check
-        if kwargs.get('menubar_close_button', None) is not None:
-            warn(
-                'menubar_close_button has been moved to title_close_button. '
-                'This alert will be removed in v4.1'
-            )
-            self.title_close_button = self._get(kwargs, 'menubar_close_button', bool)
-
         # Upon this, no more kwargs should exist, raise exception if there's more
         for invalid_keyword in kwargs.keys():
             raise ValueError('parameter Theme.{} does not exist'.format(invalid_keyword))
