@@ -43,7 +43,7 @@ from pygame_menu.locals import ORIENTATION_VERTICAL, FINGERDOWN, FINGERUP, \
     POSITION_NORTHWEST, POSITION_SOUTHEAST
 from pygame_menu.utils import check_key_pressed_valid, assert_color, assert_vector, \
     make_surface, parse_padding, get_finger_pos, uuid4, assert_cursor, assert_position
-from pygame_menu.widgets.core import Widget
+from pygame_menu.widgets.core.widget import Widget, WidgetTransformationNotImplemented
 from pygame_menu.widgets.widget.button import Button
 from pygame_menu.widgets.widget.frame import Frame
 from pygame_menu.widgets.widget.selector import check_selector_items
@@ -85,7 +85,7 @@ class DropSelect(Widget):
     :param title: Drop select title
     :param items: Items of the drop select
     :param dropselect_id: ID of the drop select
-    :param default: Index of default item to display
+    :param default: Index of default item to display. If ``None`` no item is selected
     :param onchange: Callback when changing the drop select item
     :param onreturn: Callback when pressing return on the selected item
     :param onselect: Function when selecting the widget
@@ -174,7 +174,7 @@ class DropSelect(Widget):
             title: Any,
             items: Union[List[Tuple[Any, ...]], List[str]],
             dropselect_id: str = '',
-            default: int = -1,
+            default: Optional[int] = None,
             onchange: CallbackType = None,
             onreturn: CallbackType = None,
             onselect: CallbackType = None,
@@ -215,7 +215,7 @@ class DropSelect(Widget):
             *args,
             **kwargs
     ) -> None:
-        assert isinstance(default, int)
+        assert isinstance(default, (int, type(None)))
         assert isinstance(dropselect_id, str)
         assert isinstance(items, list)
         assert isinstance(open_middle, bool)
@@ -224,6 +224,8 @@ class DropSelect(Widget):
 
         # Check items list
         check_selector_items(items)
+        if default is None:
+            default = -1
         assert default >= -1, \
             'default position must be equal or greater than zero'
         assert default < len(items), \
@@ -587,7 +589,7 @@ class DropSelect(Widget):
 
     def scrollh(self, value: NumberType) -> 'DropSelect':
         """
-        Scroll to horizontal value.
+        Scroll drop frame to horizontal value.
 
         :param value: Horizontal scroll value, if ``0`` scroll to left; ``1`` scroll to right
         :return: Self reference
@@ -598,7 +600,7 @@ class DropSelect(Widget):
 
     def scrollv(self, value: NumberType) -> 'DropSelect':
         """
-        Scroll to vertical value.
+        Scroll drop frame to vertical value.
 
         :param value: Vertical scroll value, if ``0`` scroll to top; ``1`` scroll to bottom
         :return: Self reference
@@ -670,10 +672,10 @@ class DropSelect(Widget):
             else:
                 self._drop_frame.set_position(*self._compute_position_middle())
             for w in self._option_buttons:
-                w.set_position_relative_to_frame()
+                w._set_position_relative_to_frame()
             if self._placeholder_add_to_selection_box:
                 placeholder_button: 'Button' = self._drop_frame.get_attribute('placeholder_button')
-                placeholder_button.set_position_relative_to_frame()
+                placeholder_button._set_position_relative_to_frame()
             self._drop_frame.update_position()
         return self
 
@@ -684,29 +686,28 @@ class DropSelect(Widget):
         return self
 
     def scale(self, *args, **kwargs) -> 'DropSelect':
-        return self
+        raise WidgetTransformationNotImplemented()
 
     def resize(self, *args, **kwargs) -> 'DropSelect':
-        return self
+        raise WidgetTransformationNotImplemented()
 
     def set_max_width(self, *args, **kwargs) -> 'DropSelect':
-        return self
+        raise WidgetTransformationNotImplemented()
 
     def set_max_height(self, *args, **kwargs) -> 'DropSelect':
-        return self
+        raise WidgetTransformationNotImplemented()
 
     def rotate(self, *args, **kwargs) -> 'DropSelect':
-        return self
+        raise WidgetTransformationNotImplemented()
 
     def flip(self, *args, **kwargs) -> 'DropSelect':
-        return self
+        raise WidgetTransformationNotImplemented()
 
     def _draw(self, surface: 'pygame.Surface') -> None:
         surface.blit(self._surface, self._rect.topleft)
 
     def draw_after_if_selected(self, surface: Optional['pygame.Surface']) -> 'DropSelect':
-        if self.is_selected() and self._selection_effect_draw_post:
-            self._selection_effect.draw(surface, self)
+        super(DropSelect, self).draw_after_if_selected(surface)
         if self.active and self.is_visible():
             self._check_drop_made()
 
@@ -905,6 +906,9 @@ class DropSelect(Widget):
             raise ValueError('any item has been selected yet as index is -1')
         return self._items[self._index], self._index
 
+    def value_changed(self) -> bool:
+        return self._index != self._default_value
+
     def _down(self) -> None:
         """
         Move current selection down.
@@ -1006,6 +1010,9 @@ class DropSelect(Widget):
                 btn.set_background_color(self._selection_box_bgcolor)
                 btn.update_font({'color': self._selection_option_font_style['color']})
 
+        # Force render
+        self._render()
+
     def update_items(self, items: Union[List[Tuple[Any, ...]], List[str]]) -> None:
         """
         Update drop select items.
@@ -1190,7 +1197,7 @@ class DropSelect(Widget):
                 return True
 
             # Press keys which active the drop but not apply
-            elif keydown and (event.key == pygame.K_TAB):
+            elif keydown and (event.key == ctrl.KEY_TAB):
                 self._toggle_drop()
                 return True
 
