@@ -39,7 +39,7 @@ from pygame_menu.font import FontType, assert_font
 from pygame_menu.locals import FINGERUP
 from pygame_menu.utils import check_key_pressed_valid, assert_color, assert_vector, \
     make_surface, get_finger_pos
-from pygame_menu.widgets.core import Widget
+from pygame_menu.widgets.core.widget import Widget, WidgetTransformationNotImplemented
 
 from pygame_menu._types import Any, CallbackType, Union, List, Tuple, Optional, \
     ColorType, NumberType, Tuple2NumberType, Tuple2IntType, NumberInstance, \
@@ -116,7 +116,7 @@ class ToggleSwitch(Widget):
     _switch_font_rendered: List['pygame.Surface']
     _switch_height: int
     _switch_height_factor: float
-    _switch_margin: Tuple2NumberType
+    _switch_margin: Tuple2IntType
     _switch_pos: Tuple2IntType
     _switch_width: int
     _total_states: int
@@ -146,7 +146,7 @@ class ToggleSwitch(Widget):
             switch_border_color: ColorInputType = (40, 40, 40),
             switch_border_width: int = 1,
             switch_height: NumberType = 1.25,
-            switch_margin: Tuple2NumberType = (25, 0),
+            switch_margin: Tuple2IntType = (25, 0),
             *args,
             **kwargs
     ) -> None:
@@ -171,7 +171,7 @@ class ToggleSwitch(Widget):
         assert 2 <= self._total_states, 'the minimum number of states is 2'
         assert 0 <= default_state < self._total_states, 'invalid default state value'
 
-        # Check font sizes
+        # Check fonts
         if state_text_font is not None:
             assert_font(state_text_font)
         assert isinstance(state_text_font_size, (int, type(None)))
@@ -190,7 +190,7 @@ class ToggleSwitch(Widget):
         assert slider_height_factor > 0, 'slider height factor cannot be negative'
         assert slider_thickness >= 0, 'slider thickness cannot be negative'
         assert isinstance(slider_vmargin, NumberInstance)
-        assert_vector(switch_margin, 2)
+        assert_vector(switch_margin, 2, int)
         assert isinstance(switch_height, NumberInstance) and switch_height > 0, \
             'switch height factor cannot be zero or negative'
         assert isinstance(state_color, tuple) and len(state_color) == self._total_states
@@ -229,6 +229,7 @@ class ToggleSwitch(Widget):
             infinite = True
 
         # Store properties
+        self._default_value = default_state
         self._switch_border_color = switch_border_color
         self._switch_border_width = switch_border_width
         self._infinite = infinite
@@ -271,24 +272,25 @@ class ToggleSwitch(Widget):
         assert isinstance(state, int), 'state value can only be an integer'
         assert 0 <= state < self._total_states, 'state value exceeds the total states'
         self._state = state
+        self._render()
 
     def scale(self, *args, **kwargs) -> 'ToggleSwitch':
-        return self
+        raise WidgetTransformationNotImplemented()
 
     def resize(self, *args, **kwargs) -> 'ToggleSwitch':
-        return self
+        raise WidgetTransformationNotImplemented()
 
     def set_max_width(self, *args, **kwargs) -> 'ToggleSwitch':
-        return self
+        raise WidgetTransformationNotImplemented()
 
     def set_max_height(self, *args, **kwargs) -> 'ToggleSwitch':
-        return self
+        raise WidgetTransformationNotImplemented()
 
     def rotate(self, *args, **kwargs) -> 'ToggleSwitch':
-        return self
+        raise WidgetTransformationNotImplemented()
 
     def flip(self, *args, **kwargs) -> 'ToggleSwitch':
-        return self
+        raise WidgetTransformationNotImplemented()
 
     def get_value(self) -> Any:
         return self._state_values[self._state]
